@@ -126,7 +126,7 @@ class Table:
                     "table_id": self._id,
                 },
             ).json()
-            logging.info("dropped %s: %s", self._id, res)
+            logging.debug("dropped %s: %s", self._id, res)
         except FileNotFoundError:
             logging.info("table %s does not exist", self._id)
 
@@ -172,11 +172,11 @@ class Table:
 
     def aggregate(
         self,
-        by: str = '"TOTAL"',
-        query: str = "",
+        group_by: str = "",
+        filter: str = "",
         aggr: Union[dict, None] = None,
-        timeout: float = 30.0,
         vars: Union[dict, list, None] = None,
+        **kwargs,
     ) -> pd.DataFrame:
         """
         aggregate the data after the optional `query` filter
@@ -189,6 +189,10 @@ class Table:
         if schema is None:
             raise FileNotFoundError(f"Table {self._id} does not exist")
 
+        # backward compatibility
+        filter = filter or kwargs.get("query", "")
+        group_by = group_by or kwargs.get("by", "'TOTAL'")
+
         if aggr is None:
             aggr = {}
             for field in schema:
@@ -214,7 +218,7 @@ class Table:
                 raise ValueError(f"unknown aggregation type: {a_type}")
 
         total: Union[pd.DataFrame, None] = None
-        for b in self._select(type="aggregate", by=by, inner_query=query, timeout=timeout, aggr=aggr, vars=vars):
+        for b in self._select(type="aggregate", by=group_by or "'TOTAL'", inner_query=filter, aggr=aggr, vars=vars):
             df: pd.DataFrame = b.to_pandas()
             # logging.warning("PARTIAL:\n%s", df)
             if total is None:
@@ -226,7 +230,7 @@ class Table:
             return pd.DataFrame()
 
         for field, a_type in aggr.items():
-            logging.info("field: %s, type: %s", field, a_type)
+            logging.debug("field: %s, type: %s", field, a_type)
             if a_type == "mean" or a_type == "avg":
                 total[field] = total[field + "_sum"] / total[field + "_count"]
                 total.drop(columns=[field + "_sum", field + "_count"], inplace=True)
@@ -246,12 +250,12 @@ class Table:
                 raise ValueError(f"unknown aggregation type: {a_type}")
 
         total = total.set_index("")
-        # logging.info("TOTAL:\n%s", total)
+        # logging.debug("TOTAL:\n%s", total)
         return total
 
     def _query_cursor(
         self,
-        query: str = "",
+        filter: str = "",
         cols: Optional[List[str]] = None,
         vars: Union[dict, list, None] = None,
         stream_ttl: float = 30.0,
@@ -259,17 +263,17 @@ class Table:
         tx_id: str = "",
     ) -> "Cursor":
         def scanner(scanner_cursor: str) -> Iterator[pa.RecordBatch]:
-            logging.info("selecting cursor=%s, query=%s", scanner_cursor, query)
+            logging.debug("selecting cursor=%s, filter=%s", scanner_cursor, filter)
             for b in self._select(
                 tx=tx_id,
                 type=type,
-                inner_query=query,
+                inner_query=filter,
                 cols=cols,
                 vars=vars,
                 cursor=scanner_cursor,
                 timeout=stream_ttl,
             ):
-                # logging.info("got %d rows, decoding...", b.num_rows)
+                # logging.debug("got %d rows, decoding...", b.num_rows)
                 yield b
 
         from odp.tabular_v2.client import Cursor
@@ -284,10 +288,11 @@ class Table:
 
     def select(
         self,
-        query: str = "",
-        cols: Optional[List[str]] = None,
+        filter: str = "",
+        columns: Optional[List[str]] = None,
         vars: Union[dict, list, None] = None,
         timeout: float = 30.0,
+        **kwargs,  # for backward compatibility
     ) -> "Cursor":
         """
         fetch data from the underling table
@@ -309,7 +314,10 @@ class Table:
 
         you can check the documentation of the Cursor for more information
         """
-        return self._query_cursor(query, cols, vars, timeout, "select")
+        # backward compatibility
+        filter = filter or kwargs.get("query", "")
+        columns = columns or kwargs.get("cols", None)
+        return self._query_cursor(filter, columns, vars, timeout, "select")
 
     def __enter__(self):
         if self._tx:
@@ -391,11 +399,11 @@ class Table:
                 if bm.custom_metadata:
                     if b"cursor" in bm.custom_metadata:
                         cursor = bm.custom_metadata[b"cursor"].decode()
-                        logging.info("response is partially processed with cursor %s", cursor)
+                        logging.debug("response is partially processed with cursor %s", cursor)
                     if b"stats" in bm.custom_metadata:
-                        logging.info("stats: %s", bm.custom_metadata[b"stats"].decode())
+                        logging.debug("stats: %s", bm.custom_metadata[b"stats"].decode())
 
-                # logging.info("got batch with %d rows", bm.batch.num_rows)
+                # logging.debug("got batch with %d rows", bm.batch.num_rows)
                 yield bm.batch
 
     def _insert_batch(
